@@ -30,16 +30,19 @@ public:
 	KBGroup(const QString& name);
 	~KBGroup();
 	/** */
-	QPixmap& getPixmap();
+	const QPixmap& getPixmap() { return m_pixmap; }
   /** No descriptions */
-  QString getName();
+  const QString& getName() { return m_name; }
   /** No descriptions */
-  void setPixmap(QPixmap& pixmap);
+  void setPixmap(const QPixmap& pixmap) { m_pixmap = pixmap; }
+  const QString& getIconPath() { return m_iconpath; }
+  void setIconPath(const QString &iconpath) { m_iconpath = iconpath; }
 private: // Private attributes
   /**  */
   QString m_name;
   /**  */
   QPixmap m_pixmap;
+  QString m_iconpath;
 };
 
 #endif
